<?php
/**
 * Plugin Name: myglobalHOST Automatic Image Optimizer
 * Plugin URI:  https://www.myglobalhost.in/
 * Description: Automatically resizes and compresses images upon upload to optimize them for web use.
 * Version:     1.0.0
 * Author:      myglobalHOST
 * Author URI:  https://www.myglobalhost.net/
 * License:     GPL2
 */

// Function to resize and compress images on upload
function optimize_uploaded_image( $image_id ) {
    // Get image metadata
    $metadata = wp_get_attachment_metadata( $image_id );

    // Check if it's an image and if it has sizes already generated
    if ( ! empty( $metadata['file'] ) && ! empty( $metadata['sizes'] ) ) {
        // Get the original image path
        $original_image_path = get_attached_file( $image_id );

        // Get the image editor
        $image_editor = wp_get_image_editor( $original_image_path );

        if ( ! is_wp_error( $image_editor ) ) {
            // Get the largest image size dimensions from your theme or settings
            $largest_size = get_option( 'large_size_w' ); // Adjust if needed

            // Calculate new dimensions while maintaining aspect ratio
            $original_width = $metadata['width'];
            $original_height = $metadata['height'];
            $new_width = $largest_size;
            $new_height = round( ($largest_size / $original_width) * $original_height );

            // Resize the original image
            $image_editor->resize( $new_width, $new_height, false );

            // Set compression quality (adjust as needed)
            $compression_quality = 82; // Start with a reasonable value

            // Save the resized and compressed image
            $optimized_image_path = $image_editor->save( $original_image_path, null, $compression_quality );

            // Update image metadata with the new dimensions
            $metadata['width'] = $optimized_image_path['width'];
            $metadata['height'] = $optimized_image_path['height'];
            wp_update_attachment_metadata( $image_id, $metadata );
        }
    }
}

// Hook the function to the 'add_attachment' action
add_action( 'add_attachment', 'optimize_uploaded_image' );
